/*1.5 if lending standards are strongly loosened
1.0 if lending standards are moderately loosened
0 if lending standards are unchanged
-1.0 if lending standards are moderately tightened
-1.5 if lending standards are strongly tightened*/

//   1.0 - Format Survey of Loan Officers (SLO) history according to vintage
use "$path_bs_do2\data_SLO\ECB.dta", clear
collapse banco, by(nombre_banco)
sort banco
save "$path_bs_do2\data_SLO\banco_id_nombre.dta", replace

use "$path_bs_do2\data_SLO\ECB.dta", clear
g date=string(fecha)
g year=substr(date,1,4)
g mes=substr(date,5,6)
destring year mes, force replace
g quarter=ceil(mes/3)   // capture generate date_quarter = yq(year, quarter)  capture format %tq date_quarter
sum year
tab mes
tab quarter
sort year mes
egen time=group(year mes)
sum time
local r2=r(max)
save "$path_bs_do2\data_SLO\ECB_time.dta", replace
collapse year mes quarter, by(time)
save "$path_bs_do2\data_SLO\time.dta", replace
use "$path_bs_do2\data_SLO\ECB_time.dta", clear
collapse time, by(banco)
replace time=1
save "$path_bs_do2\data_SLO\banco_id_time.dta", replace
save "$path_bs_do2\data_SLO\date_temp.dta", replace
quietly {
forv t=2/`r2' { 
use "$path_bs_do2\data_SLO\date_temp.dta", replace
replace time=`t'
joinby banco time using "$path_bs_do2\data_SLO\banco_id_time.dta", unmatched(both) update
tab _merge
drop _merge
save "$path_bs_do2\data_SLO\banco_id_time.dta", replace
}
}
joinby time using "$path_bs_do2\data_SLO\time.dta", unmatched(both) update
tab _merge
drop _merge
save "$path_bs_do2\data_SLO\banco_id_time.dta", replace
collapse year mes quarter, by(time)
save "$path_bs_do2\data_SLO\time.dta", replace

use "$path_bs_do2\data_SLO\ECB_time.dta", clear
joinby banco time using "$path_bs_do2\data_SLO\banco_id_time.dta", unmatched(both) update
tab _merge
drop _merge
sum D_1_2   // Hipotecario: oferta - estandares de aprobación de los créditos a las personas
sum D_2_2_1-D_2_2_4 D_3_2_1-D_3_2_4 // Hipotecario: Factores que explican cambios en estándares de aprobación de créditos hipotecarios
sum D_4_2_1-D_4_2_5  // Hipotecario: Condiciones crediticias para créditos hipotecarios para la vivienda
sum D_5_2   // Hipotecario: demanda - Demanda (solicitudes) por créditos
sum D_6_2_1-D_6_2_3 D_7_2_1-D_7_2_3   // Hipotecario: Factores que explican cambios en la demanda de créditos 
sum D_8 F_1_6 F_2_6  // Hipotecario: Porcentaje de refinanciamiento de crédito hipotecario ya existente
quietly {
replace D_1_2 = 0 if D_1_2==.
replace D_5_2 = 0 if D_5_2==.
recode D_1_2 0=. 1=-1.5 2=-1 3=0 4=1 5=1.5   // 0 can be either . or 0 0=. or 0=0
recode D_5_2 0=. 1=-1.5 2=-1 3=0 4=1 5=1.5
bysort time: egen temp_O_mean = median(D_1_2)  //  impute missing data with median values of the period
bysort time: egen temp_D_mean = median(D_5_2)
replace D_1_2 = temp_O_mean if D_1_2==.
replace D_5_2 = temp_D_mean if D_5_2==.      //   end of imputation
g Hip_Oacum = D_1_2 if time==1
g Hip_Dacum = D_5_2 if time==1
forv t=1/`r2' { 
g temp_Oacum = D_1_2 if time==`t'
replace Hip_Oacum = Hip_Oacum + temp_Oacum if temp_Oacum<.
replace Hip_Oacum = temp_Oacum if Hip_Oacum==.
g temp_Dacum = D_5_2 if time==`t'
replace Hip_Dacum = Hip_Dacum + temp_Dacum if temp_Dacum<.
replace Hip_Dacum = temp_Dacum if Hip_Dacum==.
drop temp*
}
}
keep year mes quarter time D_1_2 D_5_2 Hip* banco //nombre_banco
foreach var of varlist year mes quarter time {
rename `var' TS_`var'
} 
save "$path4b\\SLOhip.dta", replace
sum Hip_Oacum Hip_Dacum, d
g Hip_Oacum_TS = Hip_Oacum 
g Hip_Dacum_TS = Hip_Dacum
g Hip_Oacum_vintage = Hip_Oacum 
g Hip_Dacum_vintage = Hip_Dacum
g time=1
xtset banco TS_time
save "$path4b\\SLOhip_temp.dta", replace
save "$path4b\\SLOhip_TSvintage.dta", replace
quietly {
forv t=2/`r2' { 
use "$path4b\\SLOhip_temp.dta", clear
local t0=`t'-1
replace time=`t'
foreach M in "O" "D" {  
g temp_`M'acum0 = Hip_`M'acum if TS_time==`t0'
bysort banco: egen temp_`M'acum = mean(temp_`M'acum0)
replace Hip_`M'acum_vintage = Hip_`M'acum_TS - temp_`M'acum
replace Hip_`M'acum_vintage = . if TS_time<=`t0'
}
joinby time banco TS_time using "$path4b\SLOhip_TSvintage.dta", unmatched(both) update
tab _merge
drop _merge temp*  
save "$path4b\\SLOhip_TSvintage.dta", replace
}
}
rename banco banco_id
order banco time TS_year-TS_time, first
save "$path4b\\SLOhip_TSvintage.dta", replace
use "$path4b\\SLOhip_TSvintage.dta", clear
run "$path4b\EFHBank_CMFBankID.do" 
collapse D_1_2- Hip_Dacum_vintage, by(EFH_banco time-TS_time)
save "$path4b\\SLOhip_TSvintage2.dta", replace

use "$path4b\\SLOhip_TSvintage2.dta", clear
sum time
joinby time using "$path_bs_do2\data_SLO\time.dta", unmatched(master) update
tab _merge
drop _merge
order EFH_banco time year-quarter TS_*, first
collapse D_1_2-Hip_Dacum_vintage, by(EFH_banco year quarter TS_year TS_quarter)  //usually only one month per quarter: put everything quarterly
save "$path4b\\SLOhip_TSvintage2.dta", replace
use "$path4b\\SLOhip_TSvintage.dta", clear
sum time
joinby time using "$path_bs_do2\data_SLO\time.dta", unmatched(master) update
tab _merge
drop _merge
order banco time year-quarter TS_*, first
collapse D_1_2-Hip_Dacum_vintage, by(banco year quarter TS_year TS_quarter)
save "$path4b\\SLOhip_TSvintage.dta", replace

// 2.0 - Balance sheet data from banks
use "$path_bs_do2\data_SLO\other_bank_data\TasasVivBanco_2015_2020.dta", clear
foreach var of varlist tasa_prom tasa_min tasa_max {
replace `var' = `var'/100
}
bysort mes año: egen tasa_prom_mean = mean(tasa_prom)
bysort mes año: egen tasa_min_min = min(tasa_min)
bysort mes año: egen tasa_max_max = max(tasa_max)
bysort banco_id mes año: g dif_prom = tasa_prom - tasa_prom_mean
bysort mes año banco_id: g dif_MeanMax = tasa_max - tasa_prom_mean
bysort mes año banco_id: g dif_MeanMin = tasa_prom_mean - tasa_min
run "$path4b\EFHBank_CMFBankID.do" 
collapse dif_prom dif_MeanMax dif_MeanMin, by(EFH_banco)  //  EFH_banco banco_id
save "$path4b\\Banco_tasa_dif.dta", replace

use "$path_bs_do2\data_SLO\\old\Bancos_FusionRED.dta", clear
sum banco cluster fecha year month act_con-act_tot roa roe rof_act iac rea_imp res_imp
rename banco banco_id
g quarter=ceil(month/3)
collapse act_tot roa roe, by(banco cluster year quarter)
replace act_tot = ln(act_tot)
replace roa = roa/100
replace roe = roe/100
save "$path4b\\Banco_assets.dta", replace
run "$path4b\EFHBank_CMFBankID.do" 
drop if EFH_banco>=900
collapse (mean) act_tot roa roe (lastnm) cluster, by(EFH_banco year quarter)
save "$path4b\\Banco_assets2.dta", replace


// 3.0 - Join SLO and banks' balance sheet data with EFH data
use "$path4b\\EFH_BancoMort_Tasas.dta", clear
joinby year_efh folio_efh using "$path4b\\HipReneg3.dta", unmatched(both) update  // "$path4b\\HipReneg2.dta"
tab _merge   //sum Ren* if _merge!=3 (extra Observations are for Time series of Mortgage Rates)  //keep if _merge==3
drop _merge  // d_chotp valor_vp dhip_vp deuda_hip_otp1 deuda_hip_otp2 deuda_hip_otp3  // pwcorr d_vp d_chvp dhip_vp
joinby year_efh folio_efh using "$path4b\\efh_income_age.dta", unmatched(master) update
tab _merge
drop _merge
drop yrCMortg_VIV
egen yrMatCMortg_OTP = rowmax(yrMatCMortg_otp*)
egen yrMatCMortg_VIV = rowmax(yrMatCMortg_vp yrMatCMortg_OTP)
egen yrCMortg_OTP = rowmin(yrCMortg_otp*) 
egen yrCMortg_VIV = rowmin(yrCMortg_*) 
egen mCMortg_OTP = rowmin(mCMortg_otp*) 
egen mCMortg_VIV = rowmin(mCMortg_vp mCMortg_OTP) 
egen RCmortg_OTP = rowmax(RCmortg_otp*)
egen RCmortg_VIV = rowmax(RCmortg_vp RCmortg_OTP)
quietly { 
recode tedad 1=2
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
recode Hinstitucion_`Prop' 6/9=.
}
foreach var0 in "Hbancofin" "Hinstitucion" { 
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
foreach P2 in "vp" "otp1" "otp2" "otp3" { 
replace `var0'_`Prop' = `var0'_`P2' if `var0'_`Prop'==. & RenMortg_`Prop'<.
}
}
}
foreach Prop in "vp" "otp1" { // "otp2" "otp3"
mlogit Hinstitucion_`Prop' i.(tedad) RenMortg_`Prop' ln_ytot_p_h
predict p1 p2 p3 p4 p5 //p6 
g Pa = uniform()
g Oa = 1 if RenMortg_`Prop'<.
forv k1=2/5  {   //2/6
local k2=`k1'-1
replace p`k1' = p`k1'+p`k2'
replace Oa=`k1' if Pa>p`k2' & Pa<=p`k1'
}
replace Hinstitucion_`Prop'=Oa if Hinstitucion_`Prop'==. 
drop Pa Oa p1-p5 //p6
}
} 
quietly { 
foreach Prop in "vp" "otp1" { // "otp2" "otp3"
g EFH_banco = Hbancofin_`Prop'
recode EFH_banco 2=1 5=4 7=6 9=8 12=11 17=21 20=19 16=15 18=15 14=21  //.=21
mlogit EFH_banco i.(tedad) RenMortg_`Prop' ln_ytot_p_h
predict p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11
g Pa = uniform()
g Oa = 1 if RenMortg_`Prop'<.
forv k1=2/11  {
local k2=`k1'-1
replace p`k1' = p`k1'+p`k2'
replace Oa=`k1' if Pa>p`k2' & Pa<=p`k1'
}
recode Oa 1=1 2=3 3=4 4=6 5=8 6=10 7=11 8=13 9=15 10=19 11=21
replace Hbancofin_`Prop'=Oa if Hbancofin_`Prop'==. & Hinstitucion_`Prop'==2 
drop EFH_banco Pa Oa p1-p11
}
} 
egen Hbancofin_OTP = rowmin(Hbancofin_otp*)
egen Hbancofin_VIV = rowmin(Hbancofin_vp Hbancofin_OTP)
egen Hinstitucion_OTP = rowmin(Hinstitucion_otp*)
foreach var of varlist Hinstitucion_otp* {
replace Hinstitucion_OTP=2 if `var' ==2
}
egen Hinstitucion_VIV = rowmin(Hinstitucion_vp Hinstitucion_OTP)
foreach var of varlist Hinstitucion_* {
replace Hinstitucion_VIV=2 if `var' ==2
}
drop tedad quintile_h ln_ytot_p_h ytot_p_h
foreach Prop in "VIV" "vp" "otp1" "otp2" "otp3" "OTP" { 
replace Hbancofin_`Prop'=21 if Hinstitucion_`Prop'==2 & Hbancofin_`Prop'==.
}
egen Htasa_OTP = rowmin(Htasa_otp*)
egen Htasa_VIV = rowmin(Htasa_vp Htasa_OTP)  
capture drop year
sum Hta* 
quietly { // sum yrC* RC* Htasa_*
foreach var of varlist Htasa_* {
replace `var' = `var'/100
}
foreach Prop in "VIV" "vp" "OTP" "otp1" "otp2" "otp3" {  // Put variables in log //
g EFH_banco = Hbancofin_`Prop'
run "$path4b\EFHBank_CMFBankID2.do"      // Condell=CorpBanca
recode EFH_banco 2=1 5=4 7=6 9=8 12=11 17=21 20=19 16=15 18=15 .=21 // ATLAS=Chile Desarrollo=SCOTIA BCI NOVA=BCI BANEFE=Santander BBVA Express=BBVA
joinby EFH_banco using "$path4b\\Banco_tasa_dif.dta", unmatched(both) update  // Ripley/Paris=Falabella Penta=Otro
tab _merge if EFH_banco<.  //tab EFH_banco  if _merge!=3
g Tasa0 = RCmortg_`Prop'
g Tasa1 = Tasa0 + dif_prom + dif_MeanMax
g Tasa2 = Tasa0 + dif_prom - dif_MeanMin
replace Htasa_`Prop' = min( max(Tasa2,Htasa_`Prop'), Tasa1) if Htasa_`Prop'<. 
replace Htasa_`Prop' = RCmortg_`Prop' if Htasa_`Prop'==. & RenMortg_`Prop'<. 
capture drop Tasa0 Tasa1 Tasa2 _merge

g year = max(2003, yrCMortg_`Prop') if yrCMortg_`Prop'<.
g quarter = ceil(mCMortg_`Prop'/3) if mCMortg_`Prop'<.
bysort year_efh: egen temp_year=median(year)
replace year = temp_year if year==. & RenMortg_`Prop'<. 
replace quarter = 4 if quarter==. & RenMortg_`Prop'<. 
g TS_year = year_efh
g TS_quarter = 4 if year_efh<2014
replace TS_quarter = 2 if year_efh>=2014
sum year_efh
joinby banco_id year quarter TS_year TS_quarter using "$path4b\\SLOhip_TSvintage.dta", unmatched(master) update
tab _merge
drop _merge
joinby EFH_banco year quarter TS_year TS_quarter using "$path4b\\SLOhip_TSvintage2.dta", unmatched(master) update
tab _merge
rename Hip_Oacum_vintage Hip_Oacum_vintage_`Prop'
rename Hip_Dacum_vintage Hip_Dacum_vintage_`Prop'
drop _merge year quarter temp_year dif_prom-Hip_Dacum_TS

g year = min(2015,year_efh)
g quarter = 4 if year_efh<2014
replace quarter = 2 if year_efh>=2014
joinby banco_id year quarter using "$path4b\\Banco_assets.dta", unmatched(master) update
tab _merge
drop _merge
joinby EFH_banco year quarter using "$path4b\\Banco_assets2.dta", unmatched(master) update
tab _merge
foreach var of varlist cluster-roe {
rename `var' `var'_`Prop'
}
drop _merge year quarter EFH_banco banco_id
}
}
sum Hta* Hip_* roa* roe* cluster* 
save "$path4b\\HipReneg4.dta", replace
