use "$path4b\TSRates.dta", clear // 1.0 Compute calibration parameters for renegotiation formula of Agarwal et al JMCB 2013
sort year month
egen time=group(year month)
tsset time
g dRm = L.Rmortgage
replace dRm=(Rmortgage-dRm)   //   Already divided now! /100  //g Rmortgage_adl=Rmortgage/100
sum dRm if year>=2003, d //sum Rmortgage_adl if year>=2003, d 
global Rsigma = r(sd)*sqrt(12) // Agarwal et al JMCB 2013: mortgage sigma = 0.0109
global rho = 0.05 // the real discount rate (Agarwal et al JMCB 2013)
global Fcost = ${BPP} // fixed cost of renegotiating in UF: 20 or 24 or 24.1
global fpc=0.01  // variable cost of renegotiating
global miuADL = 0.05 // Agarwal et al 2013: miu=10% (page 13). Hayre et al (2000) estimate that 5–7% of single-family homes turnover per year.
global thetaADL = ${miuADL}+0.01   // probability of exogenous refinancing (Agarwal et al 2013: use 10% or miu + 10%)
global Nmyears = 20   // number of years of new mortgage (mode in Chile EFH: 46% of the loans)
global infR = 0.03  // Inflation rate target of Central Bank of Chile
global RMop = 1 // Contracts are in Real terms

use "$path4b\\HipReneg2.dta", clear  // Calculate value of past renegotiation possibilities
sum income uf_yrq4 taxtau d*
sum Ideuda_* deuda_hip_vp deuda_hip_otp1 deuda_hip_otp2 deuda_hip_otp3
sum Ideuda_* UFm* yrCMortg* yrMatCMortg*
foreach cf in "" "A" { 
global Fcost = ${`cf'PP}
display("Fixed cost: ${Fcost}")
quietly { 
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
g Rdif`cf'_`Prop'=0 if Ideuda_`Prop'>0 & Ideuda_`Prop'<.
foreach rf in "xADL" "xSq" "xPV" { 
g m`cf'_`rf'_`Prop'=0 if Ideuda_`Prop'>0 & Ideuda_`Prop'<.
forv k=1/2  {
g PV`k'`cf'_`rf'_`Prop'=0 if Ideuda_`Prop'>0 & Ideuda_`Prop'<.
}
}
}
quietly { 
sum Rmortgage  // Time series aggregate variable
local Rmax=r(max)
forv yR=2002/2017 { //  1996-2002 are estimated values, only after 2002 are values real
forv mR=1/12 {
sum Rmortgage if year==`yR' & month==`mR'
local Rm=min( r(mean), `Rmax')
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
g nr_pays_done = (`yR'-yrCMortg_`Prop')*12 - max(1,mCMortg_`Prop')  + `mR' if yrCMortg_`Prop'>=1975 
g nr_paysC = 12*yrMatCMortg_`Prop'
replace nr_pays_done=. if nr_pays_done<=0
replace nr_pays_done=. if nr_pays_done>=nr_paysC
g Mny = (yrMatCMortg_`Prop'*12 -nr_pays_done)/12    // -anow/12

g Ideuda = Ideuda_`Prop' if nr_pays_done>0 & nr_pays_done<.
g dif = RCmortg_`Prop'-`Rm' if nr_pays_done>0 & nr_pays_done<.
replace Rdif`cf'_`Prop'=max(0,Rdif`cf'_`Prop',dif) if Ideuda>0 & Ideuda<.
g Adif=abs(dif) if nr_pays_done>0 & nr_pays_done<.
refinance_ADLoption Ideuda taxtau RCmortg_`Prop' Mny 250
refinance_ADLsqroot Ideuda taxtau RCmortg_`Prop' Mny  
refinance_PVbreakeven Ideuda taxtau RCmortg_`Prop' Mny
replace xSqr=max(xSqr,xPV)
refinance_PVgain Ideuda taxtau RCmortg_`Prop' Mny `Rm'   
refinance_PVgain2 Ideuda taxtau RCmortg_`Prop' Mny `Rm'   

foreach rf in "xADL" "xSq" "xPV" { 
replace m`cf'_`rf'_`Prop'=1+m`cf'_`rf'_`Prop' if Ideuda>0 & Ideuda<. & dif>0 & Adif>`rf'
forv k=1/2  {
replace PV`k'`cf'_`rf'_`Prop'=max(PV`k'`cf'_`rf'_`Prop',xPVgain`k') if Ideuda>0 & Ideuda<. & dif>0 & Adif>`rf'
}
}
drop nr_paysC nr_pays_done Mny xADL xSqr xPV dif Adif xPVgain1 xPVgain2 Ideuda
}
}
}
}
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
foreach rf in "xADL" "xSq" "xPV" { 
g Dr`cf'_`rf'_`Prop'= (m`cf'_`rf'_`Prop'>0) if Ideuda_`Prop'>0 & Ideuda_`Prop'<. 
}
} 
foreach Prop in "vp" "otp1" "otp2" "otp3" { 
replace RenMortg_`Prop' = (RenMortg_`Prop'==1) if RenMortg_`Prop'<.
}
}
}
drop RdifA_*
quietly { 
egen Ideuda_VIV = rowtotal(Ideud*), missing    // "VIV" "vp" "OTP" "otp1" "otp2" "otp3"
egen Ideuda_OTP = rowtotal(Ideuda_otp*), missing 
egen Rdif_VIV = rowmax(Rdif_*)
egen Rdif_OTP = rowmax(Rdif_otp*)
foreach cf in "" "A" {    //       //      //
foreach rf in "xADL" "xSq" "xPV" { 
egen Dr`cf'_`rf'_VIV = rowmax(Dr`cf'_`rf'_*) 
egen Dr`cf'_`rf'_OTP = rowmax(Dr`cf'_`rf'_otp*) 
forv k=1/2  {
egen PV`k'`cf'_`rf'_VIV = rowtotal(PV`k'`cf'_`rf'_*), missing
egen PV`k'`cf'_`rf'_OTP = rowtotal(PV`k'`cf'_`rf'_otp*), missing
}
egen m`cf'_`rf'_VIV = rowmax(m`cf'_`rf'_*)
egen m`cf'_`rf'_OTP = rowmax(m`cf'_`rf'_otp*)
}
}   //       //      //
foreach Prop in "vp" "otp1" "otp2" "otp3" { // Create ratio of value of Mortgage in previous periods
g OMortgUF_`Prop' = deuda_hip_`Prop'*max(1, rDOrigNow_`Prop')/uf_yrq4 if deuda_hip_`Prop'>0 & deuda_hip_`Prop'<.
replace RenMortg_`Prop' = 0 if RenMortg_`Prop'==. & Ideuda_`Prop'<. 
}
egen OMortgUF_OTP = rowtotal( OMortgUF_otp* ), missing
egen RenMortg_OTP = rowmax(RenMortg_otp*)
egen RenMortg_VIV = rowmax(RenMortg_vp RenMortg_OTP)
egen OMortgUF_VIV = rowtotal( OMortgUF_vp OMortgUF_OTP ), missing
egen yrCMortg_VIV = rowmax(yrCMortg_*)
egen deuda_hip_OTP=rowtotal(deuda_hip_otp*)
egen deuda_hip_VIV=rowtotal(deuda_hip_vp deuda_hip_OTP)
}
drop if folio_efh==.
save "$path4b\\HipReneg3.dta", replace
