pr def refinance_npvKost
    args F f theta Ny infR M taxtau

quietly {  // refinancing costs formula (Agarwal et al JMCB 2013: Appendix A)
// Ka=npvK is the tax real cost of refinancing as a fixed NPV (inspection costs, title/mortgage insurance, 
// filing charges, lawyers fees,  insurance, personal time, netting out all allowable
// tax deductions generated by future deductions of amortized refinancing points)

// F is the fixed cost of refinancing (ex: 2000 USD in Agarwal et al JMCB 2013, or in Chile 20UF before Portabilidad Financiera, 9 UF afterwards) 
// 100 × f = the number of points. So 1 point (1%) implies f=0.01 (Agarwal et al JMCB 2013 assume f=0.01)
// M is the mortgage size

// θ = μ + 0.10 (Agarwal et al JMCB 2013) where μ is the hazard rate of moving and 0.10 is the (approximate) hazard rate of future refinancing
//or local theta=0.05+0.05 //assume people move out of their homes (exogenously) once every 20 years, assume exogenous refinancing once every 20 years
// Ny = number of years of new mortgage (ex: Ny=25)
// infR=0.03  // assume for example inflation rate is 3% (Central Bank of Chile's inflation target)
if ${RMop}==0 {
local infRm=`infR'  //${infR}
}
if ${RMop}==1 {  // Real contract
local infRm=0
}
g real_adj = `theta'+${rho}+`infRm'
g real_value_tax_adj = ((1- exp(-real_adj*`Ny') )/`Ny')*((`infRm'+${rho})/real_adj) + `theta'        // `theta'+${rho} was incorrect

g npvK = `F'  + `f'*`M'*(1-(`taxtau'/real_adj)*real_value_tax_adj) 

drop real_adj real_value_tax_adj 

}
end
